using DelimitedFiles, Plots
using LaTeXStrings
using FFTW
using LsqFit
using Smoothers
using ColorSchemes

dir = @__DIR__#"/Users/francesco/OneDrive - Alma Mater Studiorum Università di Bologna/Lab/Data/2024/2024-01-12/"

default(fontfamily = "Times",	# default plot parameters
		aspect_ratio = :auto,
		size = (888,500),
		margin = 0.4Plots.cm,
		markersize=3, markerstrokewidth=0, lw=5,
		legend=:topright, legendfontsize=12,
		tickfontsize=12, labelfontsize=14,
		xlabel="f [MHz]",
		ylabel="PSD [arb. units]"
		)
	mvavg_n = 101 # moving averages index
## FIT MODEL

function lor(x,p)
	return p[1] .+ abs(p[2]) ./ ( 1 .+ ((x .- p[3])/p[4]).^2 )
end

# """
# Oscilloscope traces, 256us
# """

# ## FFT beat 780, 256us
# filename = "20240112-CoolRep-780-Oscilloscope-256us.CSV"
# 	data = readdlm(dir*filename, ',', skipstart=1)
# # time and voltage
# 	dt = data[2,1] - data[1,1];
# 	y780 = data[:,2]

# # FFT
# 	w780 = fft(y780)
# 	f780 = fftfreq(length(y780), 1/dt)

# # select two ROI, 15M<f<30M, 30M<f<45M
# 	j30 = findfirst([x > 30e6 for x in f780])
# 	j15 = findfirst([x > 15e6 for x in f780])

# # first ROI data, fit
# 	x780_a = f780[j15:j30]*1e-3; # in kHz
# 	y780_a = abs2.(w780[j15:j30]);
# 	y780_a = hma(y780_a, 101);
# 	par0 = [0 90.0 21.0e3 300.]
# 	fit780a = curve_fit(lor, x780_a, y780_a, vec(par0))
# 	gamma780a = round(abs(coef(fit780a)[4]))

# # second ROI data
# 	x780_b = f780[j30+1:j30*2-j15]*1e-3;
# 	y780_b = abs2.(w780[j30+1:j30*2-j15])
# 	y780_b = hma(y780_b, 101);

# 	par0 = [0 0.12 42.0e3 800.]
# 	fit780b = curve_fit(lor, x780_b, y780_b, vec(par0))
# 	gamma780b = round(abs(coef(fit780b)[4]))


# scatter(x780_a*1e-3, y780_a*10,
# 		label = "HWHM = 0.174 MHz",
# 		color="black"
# 		)
# 		plot!(x780_a*1e-3, (y780_a .+ fit780a.resid)*10,
# 				color="dodgerblue", label="")
# 		xlims!(17,23)

# savefig("/Users/francesco/Documents/julia/Img/20240112-beat780-256us-20M-v1.png")


# scatter(x780_b*1e-3, y780_b*10,
# 		label = "HWHM = 0.600 MHz", color="black")
# 		plot!(x780_b*1e-3, (y780_b .+ fit780b.resid)*10,
# 			color="dodgerblue", label="")
# 		xlims!(37,43)


# savefig("/Users/francesco/Documents/julia/Img/20240112-beat780-256us-40M-v2.png")

## FIT beat 1560

filename = "20240112-CoolRep-1560-Oscilloscope-256us.CSV"
	data = readdlm(dir*'\\'*filename, ',', skipstart=1)
# time and voltage
	dt = data[2,1] - data[1,1];
	y1560 = data[:,2]
	w1560 = fft(y1560)
	f1560 = fftfreq(length(y1560), 1/dt)

# select ROI, 15M<f<30M
	j30 = findfirst([x > 30e6 for x in f1560])
	j15 = findfirst([x > 15e6 for x in f1560])

	x1560 = f1560[j15:j30]*1e-3 # in kHz
	y1560 = abs2.(w1560[j15:j30])
	y1560 = hma(y1560, mvavg_n)


par0 = [0 3.0e6 21.0e3 500.]
	fit1560 = curve_fit(lor, x1560, y1560, vec(par0))
	gamma1560 = round(abs(coef(fit1560)[4]))
scatter(x1560*1e-3, y1560*1e-4,
			label = "",
			color=ColorSchemes.RdBu_6[6],
			)
	plot!(x1560*1e-3, (y1560 .+ fit1560.resid)*1e-4,
			color=ColorSchemes.RdBu_6[1], label="HWHM = $gamma1560 kHz")
	xlims!(18,24)
	ylims!(0,6.25)

predirlength = length(dirname(@__DIR__));	# automatic name choice
currentdir = @__DIR__;

savefig(currentdir*'\\'*currentdir[(predirlength+3):end]*".pdf")

##
# """

# Oscilloscope traces, 168us

# """

# # FFT beat 780, 168us
# filename = "20240112-CoolRep-780-Oscilloscope-168us.CSV"
# 	data = readdlm(dir*filename, ',', skipstart=1)
# # time and voltage
# 	dt = data[2,1] - data[1,1];
# 	y780 = data[:,2]

# # FFT
# 	w780 = fft(y780)
# 	f780 = fftfreq(length(y780), 1/dt)

# # select two ROI, 15M<f<30M, 30M<f<45M
# 	j15 = findfirst([x > 15e6 for x in f780])
# 	j30 = findfirst([x > 30e6 for x in f780])


# # first ROI data, fit
# 	x780_a = f780[j15:j30]*1e-3; # in kHz
# 	y780_a = abs2.(w780[j15:j30]);
# 	y780_a = hma(y780_a, mvavg_n);
# 	par0 = [0 90.0 21.0e3 300.]
# 	fit780a = curve_fit(lor, x780_a, y780_a, vec(par0))
# 	gamma780a = round(abs(coef(fit780a)[4]))

# # second ROI data
# 	x780_b = f780[j30+1:j30*2-j15]*1e-3;
# 	y780_b = abs2.(w780[j30+1:j30*2-j15])
# 	y780_b = hma(y780_b, mvavg_n)
# 	xdata = x780_b

# par0 = [0 1.0 42e3 900.]
# 	fit780b = curve_fit(lor, xdata, y780_b, vec(par0))
# 	gamma780b = round(abs(coef(fit780b)[4]))


# scatter(x780_a*1e-3, y780_a,
# 		color= "black",
# 		label = "HWHM = $gamma780a",
# 		)

# plot!(x780_a*1e-3, (y780_a .+ fit780a.resid),
# 				color="dodgerblue", label="")

# 		xlims!(17,23)

# savefig("/Users/francesco/Documents/julia/Img/20240112-beat780-168us-21M-v1.png")

# scatter(xdata*1e-3, y780_b,
# 	frame=:box, color= "black",
# 	label = "HWHM = $gamma780b"
# 		)

# plot!(xdata*1e-3, (y780_b .+ fit780b.resid),
# 		color="dodgerblue", label="")
# 	xlims!(39,45)

# savefig("/Users/francesco/Documents/julia/Img/20240112-beat780-168us-42M-v1.png")

# ## FIT beat 1560

# filename = "20240112-CoolRep-1560-Oscilloscope-168us.CSV"
# 	data = readdlm(dir*filename, ',', skipstart=1)
# # time and voltage
# 	dt = data[2,1] - data[1,1];
# 	y1560 = data[:,2]
# 	w1560 = fft(y1560)
# 	f1560 = fftfreq(length(y1560), 1/dt)

# # select ROI, 15M<f<30M
# 	j30 = findfirst([x > 30e6 for x in f780])
# 	j15 = findfirst([x > 15e6 for x in f780])

# 	x1560 = f1560[j15:j30]*1e-3 # in kHz
# 	y1560 = hma(abs2.(w1560[j15:j30]),101)
# 	par0 = [0 3.0e6 21.0e3 500.]
# 	fit1560 = curve_fit(lor, x1560, y1560, vec(par0))
# 	gamma1560 = round(abs(coef(fit1560)[4]))

# scatter(x1560*1e-3, y1560*0.25e-5,
# 		frame=:box, label = "HWHM = 0.193 MHz",
# 		legend=:topright, markersize = 2, color="black"
# 		)
# 	plot!(x1560*1e-3, .25e-5*(y1560 .+ fit1560.resid),
# 			lw=2, color="red", label="")
# 	xlims!(16,22)
# 	xlabel!(L"f\,\, \mathrm{[MHz]}", labelfontsize=14)
# 	ylabel!(L"\mathrm{PSD\,\,[arb. \, units]}")

# savefig("/Users/francesco/Documents/julia/Img/20240112-beat1560-168us-v2.png")
