using DelimitedFiles
using LaTeXStrings
using Plots
using FFTW
using Statistics
using ColorSchemes



default(fontfamily = "Times",	# default plot parameters
	aspect_ratio = :auto,
	size = (500,500),
	margin = 0.25Plots.cm,
	markersize=3, markerstrokewidth=0, lw=3,
	legend=:topright, legendfontsize=12,
	tickfontsize=12, labelfontsize=14,
	xlabel="f [kHz]", ylabel="RIN [dB/Hz]",
	xlims=(10,200), ylims=(-170,-100),
	xticks=25:25:200#, yticks=7
	)


dir = @__DIR__

filelist = readdir(dir)
	for i =length(filelist):-1:1
		if filelist[i][end-3:end] != ".dat"
		   deleteat!(filelist, i)
		end
	end


### Only Seed Laser
file1 = dir*"\\20230125\\YE4140_6.csv"
	dataSA = readdlm(file1,',', comments = true);
	Idc40 = [2.34 0.941 0.189 0.01]*1e-3;
	G40 = 1e6;
	Zin = 50;
	rbw = 1e3;
	c40 = - 30 - 10*log10(rbw) - 20*log10(G40) + 10*log10(Zin);
	rin = dataSA[3:603,3]*1.0 .+ c40 .-20*log10(Idc40[1]);
	freq = dataSA[3:603,1]*1.0

p=plot(freq*1e-3,rin, color="grey", label="Cooler, 190 mA")
	#xlims!(0,200)


### Now look at all other data
for i =length(filelist):-1:1
		if filelist[i][1:4] != "2023"
		   deleteat!(filelist, i)
	   end
end

filelistDS = filelist[1:7];
	filelistSA = filelist[8:end];
	for i =length(filelistSA):-1:1
		if !occursin("b", filelistSA[i])
			deleteat!(filelistSA, i)
		end
	end
	#deleteat!(filelistSA, 1)


VDS = [0 54 96 132.5 232.5 280.5]*1e-3; # V
	EDFAcurr = [0 1000 1200 1400 1600 1800 2000]; # mA
	G40 = 1e3;
	Rload = 25;
	Idc = VDS/Rload;
	Zin = 50;
	rbw = 1e3;
	c40 = - 30 - 10*log10(rbw) - 20*log10(G40) + 10*log10(Zin);
	# colors
	pc = [":grey",ColorSchemes.RdBu_6[6],ColorSchemes.RdBu_6[2],ColorSchemes.RdBu_6[1]]

### Only SA data now
for j = 4:-1:2
	dataSA = readdlm(dir*'\\'*filelistSA[j],'\t', comments = true);
	rin = dataSA[:,2]*1.0 .+ c40 .-20*log10(Idc[j]);
	freq = dataSA[:,1]*1.0
	lstr = string(EDFAcurr[j], " mA")
	p=plot!(freq*1e-3, rin, color=pc[j],
			frame=:box, label = lstr)
			#xlabel!(L"f\,\mathrm{ [kHz]}", labelfontsize=16)
			#ylabel!(L"{\mathrm{RIN\, [dB/Hz]}}")
#plot!(vec([0, 250]),10.0*log10(2*1.6e-19/Idc40[1] + 4*1.38e-23*300e-3/Idc40[1]^2)*vec([1 1]), lw=2,
#			color=pc[1], ls=:dash, label=:false)
end
display(p)

predirlength = length(dirname(@__DIR__));	# automatic name choice
currentdir = @__DIR__;

#savefig(currentdir*'\\'*currentdir[(predirlength+3):end]*".pdf")