using DelimitedFiles
using LaTeXStrings
using Plots
using FFTW
using Statistics
using ColorSchemes

default(fontfamily = "Times",	# default plot parameters
	aspect_ratio = :auto, frame=:box,
	size = (500,500),
	margin = 0.2Plots.cm,
	markersize=3, markerstrokewidth=0, lw=2,
	legend=:topright, legendfontsize=12,
	tickfontsize=12, labelfontsize=14,
	xlabel="f [kHz]", ylabel="RIN [dB/Hz]",
	xlims=(0,20), ylims=(-115,-90),
	xticks=0:5:20, yticks=7
	)


dir = @__DIR__
	filelist = readdir(dir)
	for i =length(filelist):-1:1
		if filelist[i][end-3:end] != ".dat"
		   deleteat!(filelist, i)
		end
	end

ColPal = ["grey",ColorSchemes.RdBu_6[6],ColorSchemes.RdBu_6[2],ColorSchemes.RdBu_6[1]]
	EDFAcur = [0, 1000, 1200, 1400];
	Vdc = [1, 1.7, 3.2, 4.6, 6.06];
	p = plot()

for ifile = 4:-1:2
#ifile = 2
	DSfft = readdlm(dir*"\\"*filelist[ifile+1])
	rbw = DSfft[2,4];
	rms = DSfft[3,4];
	DSfft = DSfft[6:end,:]
	# normalize
	n1 = sum(DSfft[:,2].^2)# / rms^2;
	DSfft[:,2] = DSfft[:,2]/sqrt(200);
	#
	println("n1 = ", n1)
	println("rms2 =", rms^2)
	df = DSfft[2,1]-DSfft[1,1];
	lstr = string(EDFAcur[ifile]," mA");
	rin = 20 * log10.(DSfft[:,2]) .- 20*log10(Vdc[ifile]) .-0*log10.(rbw);
	plot!(DSfft[:,1]*1e-3, rin,
		color=ColPal[ifile], label = lstr)
end

display(p)

# predirlength = length(dirname(@__DIR__));	# automatic name choice
# currentdir = @__DIR__;

# savefig(currentdir*'\\'*currentdir[(predirlength+3):end]*".pdf")