using DelimitedFiles
using LaTeXStrings
using Plots
using FFTW
using Statistics
using PlutoUI
using ColorSchemes
using NaNStatistics

default(fontfamily = "Times Roman",	# default plot parameters
		aspect_ratio = :auto,
		size = (888,500),
		minorticks=9, minorgrid=false,
		margin = 0.5Plots.cm)



filelist = readdir(@__DIR__)				# reading all .dat files in the directory
	for i = length(filelist):-1:1
		if filelist[i][end-3:end] != ".CSV"
		deleteat!(filelist, i)
		end
	end

p =	plot(frame=:box, legend=:topleft,					# prepare the plot
			legendfontsize=12, tickfontsize=12, lw=4,
			xticks=10, yticks=[1e-21,1e-20,1e-19,1e-18])
			xlims!(1e1, 5e5)
			ylims!(5e-22, 5e-18)

#for j = length(filelist):1:-1							# plot only first file (the stitched one)
	data = readdlm(string(@__DIR__, '\\', filelist[1]), ',', comments = true)#, skipstart=1);
	#lstr = filelist[j][6:7];
#end
	data[:,2] = ( 10 .^(data[:,2]./20) ./10^(5) ).^2;

	for i in 65405:124339			#adjusting for different BW
		data[i,2] = data[i,2] / 10;
	end
	for i in 124340:183321
		data[i,2] = data[i,2] / 100;
	end
	
plot!(data[:,1]*1.0, data[:,2],
		c=:lightgrey, legend=false,
		#palette = :RdBu_6, marker=:circle, markersize=3, markerstrokewidth=0,
		#label = string(lstr," mA"), legend=:topright,
		xaxis=:log, yaxis=:log)

smooth = movmean(data[:,2], 256);
plot!(data[:,1], smooth,
		c=ColorSchemes.RdBu_6[6], linewidth=3, legend=false,
		xaxis=:log, yaxis=:log)
	

xlabel!("f [Hz]", labelfontsize=14)
ylabel!("PSDᵢ [A²/Hz]")


# predirlength = length(dirname(@__DIR__));	# automatic name choice
# currentdir = @__DIR__;

# savefig(currentdir*'\\'*currentdir[(predirlength+3):end]*".pdf")