using Plots
using LsqFit
using LaTeXStrings
using ColorSchemes


predirlength = length(dirname(@__DIR__));	# automatic name choice
currentdir = @__DIR__;

default(fontfamily = "Times",	# default plot parameters
	aspect_ratio = :auto,
	size = (500,500),
	margin = 0Plots.cm,
	markercolor=ColorSchemes.RdBu_6[6], markersize=4, markerstrokewidth=2,
    linecolor=ColorSchemes.RdBu_6[6], lw=3,
	legend=:topleft, legendfontsize=12,
	tickfontsize=12, labelfontsize=14,
	axis=:log,
	minorticks=9, minorgrid=true,
	#xlabel="τ [s]", ylabel="σₚ/⟨P⟩ ; σₑₑₑ/⟨deg⟩"#,
	xlims=(7,325),
    ylims=(0.01,125),
	#xticks=5, yticks=3
	)


data = [
    32.8 0.16 0.4156;
    33.0 0.03 0.4135;
    33.2 0.06 0.4114;
    33.4 0.26 0.4094;
    33.6 0.56 0.4074;
    33.8 0.88 0.4053;
    34.0 1.12 0.4033;
    34.2 1.20 0.4012;
    34.4 1.05 0.3992;
    34.6 0.72 0.3971;
    34.8 0.35 0.3951;
    35.0 0.12 0.3932;
    35.2 0.08 0.3911;
    35.4 0.27 0.3893;
    35.6 0.68 0.3872;
    35.8 1.17 0.3852;
    36.0 1.57 0.3833;
    36.2 1.73 0.3811;
    36.4 1.50 0.3793;
    36.6 0.99 0.3773;
    36.8 0.41 0.3753;
    37.0 0.12 0.3733;
    37.4 1 0.3695;
    37.8 5 0.3657;
    38.2 7 0.3619;
    38.4 7 0.3600;
    38.6 6 0.3580;
    39.0 2 0.3544;
    39.4 1 0.3506;
    39.6 4 0.3487;
    39.8 11 0.3469;
    40.0 22 0.3451;
    40.2 37 0.3433;
    40.4 53 0.3414;
    40.6 69 0.3396;
    40.8 84 0.3378;
    41.0 93 0.3360;
    41.2 97 0.3342;
    41.4 92 0.3323;
    41.6 82 0.3305;
    41.8 71 0.3289;
    42.0 55 0.3270;
    42.2 39 0.3252;
    42.4 24 0.3234;
    42.6 12 0.3217;
    42.8 5 0.3199;
    43.0 1.06 0.3183;
    43.2 0.14 0.3164;
    43.4 1.56 0.3147;
    43.6 3 0.3131;
    43.8 6 0.3131;
    44.0 7 0.3097;
    44.2 7 0.3081;
    44.4 6 0.3063;
    44.6 4 0.3046;
    44.9 2 0.3029;
    45.0 1 0.3013
]

T_nominale = data[:,1];
P_PD = data[:,2];
rt = data[:,3];

logalpha = log.(rt./(1 .- rt))

T0 = 317.11;
B = 3456;
BT0 = B/T0;


T_corr = (B./(logalpha .+ BT0)) .- 273.15

Plots.plot(T_nominale,T_corr)
#savefig("T.png")

##
function f1(x,p)
    x1 = pi*(x .- p[1])/p[2];
    return p[3] .+ p[4] * (sin.(x1)./x1).^2
end

datarange = P_PD .< 10; #select data at low power
    xdata = T_corr[datarange]
    ydata = P_PD[datarange]
    par0 = [65.0, 3.0, 0.0, 95.0]
    fit1 = curve_fit(f1, xdata, ydata, par0)
    fit2 = curve_fit(f1, T_corr, P_PD, par0)

xfit = [50:0.1:75;]
    yfit1 = f1(xfit, fit1.param)
    yfit2 = f1(xfit, fit2.param)

# scatter(T_corr, P_PD, frame=:box)
#     plot!(xfit, yfit1, lw=2)
#     plot!(xfit, yfit2, lw=2)

### QUESTO
# plot(rt./(1 .-rt) * 5, P_PD/maximum(P_PD),
#         label="", frame=:box, marker=:circle)#,
#         #xlims=(1,2600), ylims=(1e-3,1e-1),
# 	    #xticks=5, yticks=3)
#  		 #legendfontsize=12, tickfontsize=12, lw=2)
#     #plot!(xfit, yfit2/maximum(P_PD), lw=2,
#     #        color="dodgerblue", label="fit", legend=:topleft)
#     xlabel!("Thermistor Resistance [kΩ] ")#, labelfontsize=16)
#     ylabel!("SH Relative Power ")

#     savefig(currentdir*'\\'*currentdir[(predirlength+3):end]*"-T.pdf")


# scatter(T_corr, fit1.resid)
#     scatter!(T_corr, fit2.resid)


## efficiency

#   I[mA]   1560[dBm] 780[mW]
data2=[
    1187	24.9	93;
    1150	24.5	80;
    1100	23.9	63;
    1050	23.3	48;
    1000	22.5	35;
    950	    21.5	24;
    900	    20.4	15;
    850	    19.0	8;
    800	    17.0	3.72;
    750	    13.9	0.83;
    700	    8.8	    0.05]

EDFAcurr = data2[:,1];
    EDFAdBm = data2[:,2];
    P1560 = 10 .^ (0.1*EDFAdBm);
    P1560c = P1560*10^(-0.09);
    P780 = data2[:,3];
    P780dBm = 10*log10.(P780);
    eff = P780 ./ P1560;

# plot(EDFAdBm, P780dBm,
#              label="", frame=:box, marker=:circle,
#      		 legendfontsize=12, tickfontsize=12, lw=2)
#         #plot!(xfit, yfit2/maximum(P_PD), lw=2,
#         #        color="dodgerblue", label="fit", legend=:topleft)
#         xlabel!("EDFA power [dBm] ", labelfontsize=16)
#         ylabel!("SH power [dBm]")

# plot(EDFAdBm, P780dBm .- EDFAdBm,
#         label="", frame=:box, marker=:circle,
#         legendfontsize=12, tickfontsize=12, lw=2)
#         xlabel!(L"\mathrm{EDFA\, power\, [dBm]}", labelfontsize=16)
#         ylabel!(L"\mathrm{SH\, efficiency, }P_{780}/P_{1560}\, \mathrm{ [dB]}")

# #savefig("/Users/francesco/Documents/julia/Img/20230523-SHG-EffVsEDFA.png")

# plot(P1560c[1:end-1], P780[1:end-1]./ (P1560c[1:end-1].^2) *1e3 ,
#         color="purple", label="", frame=:box, marker=:circle, markersize=5,
#         legendfontsize=12, tickfontsize=12, lw=2)
#         xlabel!(L"P_{1560} \mathrm{\, [mW]}", labelfontsize=16)
#         ylabel!(L"P_{780}/P_{1560}^2\, [\mathrm{W}^{-1}]")

# #savefig("/Users/francesco/Documents/julia/Img/20230523-SHG-NLeffVsEDFA.png")

# function f2(x,p)
#     return p[1] .+ p[2]*x
# end

# scatter(EDFAcurr, P1560, legend=:false, frame=:box,
#     ylabel = "power 1560 [mW]", xlabel = "EDFA current [mA]")

# #savefig("/Users/francesco/Documents/julia/Img/20230523-EDFA-P1560VsCurr.png")

## QUESTO
plot(P1560, P780, legend=:false, frame=:box, marker=:circle,
    xlabel = "Power 1560 [mW]", ylabel = "Power 780 [mW]")

     savefig(currentdir*'\\'*currentdir[(predirlength+3):end]*"-PwrPwr.pdf")


# fit11 = curve_fit(f2, P1560[1:3], eff[1:3], [0.1, 0.0001])
#     fit12 = curve_fit(f2, P1560[end-3:end], eff[end-3:end], [0.1, 0.0001])
#     xfit = [0:320;]
#     plot!(xfit, f2(xfit, fit11.param))
#     plot!(xfit, f2(xfit, fit12.param))
