import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
from scipy.interpolate import interp1d
TEMP_PRESENT = True # True if also temperature measurement is present

mult_factor = 10 # sqrt(10) for gain 10dB, 10 for gain 0dB on PD
# import transmitted data
filename_trans = '20240313-SHG_PWRStab_New\SHG_PWR_trans_PWM.csv'
data_trans = pd.read_csv(filename_trans, sep=';', header=2, encoding='ISO-8859-1',names=['T [ms]','PW [W]','drop'])
data_trans = data_trans.drop(labels = 'drop', axis=1)
time_trans = data_trans['T [ms]'] / 1000 # s
power_trans = data_trans['PW [W]'] * 1000 # mW

time_max = 5999 # s
index = time_trans < time_max
time_trans = time_trans[index]
power_trans = power_trans[index]

# import reflected data
filename_refl = '20240313-SHG_PWRStab_New\SHG_PWR_Refl_PD_Gain0.csv'
data_refl = pd.read_csv(filename_refl, header=1, names=['T [s]','PW [V]'])
time_refl = (data_refl['T [s]'] - data_refl['T [s]'][0]) # s
power_refl = (data_refl['PW [V]'] - 0.032) * 0.11693 * mult_factor # mW

interp_f = interp1d(time_refl, power_refl)
power_refl_interp = interp_f(time_trans)

# # import temperature data
# if TEMP_PRESENT:
#   filename_Temp = '10_Temp.csv'
#   data_Temp = pd.read_csv(filename_Temp, header=1, encoding='ISO-8859-1', names=['mode','T [s]','Temp [C]'])
#   data_Temp = data_Temp.drop(labels='mode', axis = 1)

#   time_temp = (data_Temp['T [s]'] - data_Temp['T [s]'][0]) # s
#   meas_temp = data_Temp['Temp [C]'] # C

#   interp_f = interp1d(time_temp, meas_temp)
#   temp_interp = interp_f(time_trans)


# ----------------------------------------------- #
tot_pw = power_refl_interp + power_trans
avg_power = np.mean(tot_pw)

theta = np.arctan(power_trans / power_refl_interp)
avg_theta = np.mean(theta*180/np.pi)

# if TEMP_PRESENT:
#   avg_temp = np.mean(meas_temp)


# ------------------------Plot Power----------------------- #
_, ax = plt.subplots(1, 1, figsize=(9, 5))
ax.plot(time_trans, power_refl_interp, label = 'Si PD (R)')
ax.plot(time_trans, power_trans, label = 'PWM (T)')
ax.plot(time_trans, tot_pw, label = 'Total')
ax.set_title('Transmitted and Reflected PW from PBS')
ax.set_ylabel('PW [mW]')
ax.set_xlabel('t [s]')
ax.grid()
ax.legend()
plt.show()

# # ----------------Plot Temp----------------------------#
# if TEMP_PRESENT:
#   _, ax = plt.subplots(1, 1, figsize=(9, 4))
#   ax.plot(time_trans, temp_interp)
#   ax.set_ylabel('Temp [°C]')
#   ax.set_xlabel('t [s]')
#   ax.set_title('Temperature')
#   ax.grid()
#   plt.show()

# -----------------------Plot Angle------------------------ #
_, ax = plt.subplots(1, 1, figsize=(9, 5))
ax.plot(time_trans, theta*180/np.pi, label = 'theta')
ax.set_title('Polarization angle in time')
ax.set_ylabel('theta [deg]')
ax.set_xlabel('t [s]')
ax.grid()
ax.legend()
plt.show()

#------------------------ Allan Variance ---------------------#
from allan_variance_analysis import *

(o_tau_theta, o_dev_theta, _, _) = ComputeAllan(theta*180/np.pi)
(o_tau_p, o_dev_p, _, _) = ComputeAllan(tot_pw)
# if TEMP_PRESENT:
#   (o_tau_temp, o_dev_temp, _, _) = ComputeAllan(temp_interp)

#------------------------ Write to File -----------------------#
directory_path = '20240313-SHG_PWRStab_New'
if not os.path.exists(directory_path):
        os.mkdir(directory_path)
allanfile = f'{directory_path}/' + 'SHG_Pol_data-Variances.csv'
AllanRes = {
    'o_tau_theta': o_tau_theta,
    'o_dev_theta': o_dev_theta,
    'o_tau_p': o_tau_p,
    'o_dev_p': o_dev_p
    }
AllanData = pd.DataFrame(AllanRes)
AllanData.to_csv(allanfile)

# -------------- Plot Relative deviation -------------------- #
_, ax = plt.subplots(1, 1, figsize=(9, 5))
ax.loglog(o_tau_p, np.sqrt(o_dev_p / avg_power), label = 'Power')
ax.loglog(o_tau_theta, np.sqrt(o_dev_theta / avg_theta), label='Pol Angle')
# if TEMP_PRESENT:
#   ax.loglog(o_tau_temp, np.sqrt(o_dev_temp / avg_temp), label='Temp')
ax.set_ylabel(r'$\sigma_M/M$')
ax.set_xlabel(r'$\tau$ [s]')
ax.set_title('Realtive Allan deviation')
ax.grid()
ax.legend()
plt.show()

