using DelimitedFiles
using LaTeXStrings
using Plots
using Statistics
using ColorSchemes

default(fontfamily = "Times",	# default plot parameters
	aspect_ratio = :auto, frame=:box,
	size = (500,500),
	margin = 0.25Plots.cm,
	markersize=3, markerstrokewidth=0, lw=3,
	legend=:topleft, legendfontsize=12,
	tickfontsize=12, labelfontsize=14,
	axis=:log,
	minorticks=9, minorgrid=false,
	xlabel="τ [s]", ylabel="σₚ/⟨P⟩ ; σₑₑₑ/⟨deg⟩",
	xlims=(1,2600), ylims=(1e-3,1e-1),
	xticks=5, yticks=3
	)


dir = @__DIR__
	file = "SHG_Pol_data-Variances.csv"
data = readdlm(dir*"\\"*file,',', comments = true, skipstart=1);
tau = data[:,2];
PWR = data[:,5].^(0.5)#./mean(data[:,5]); # VA DIVISO PER LA POTENZA MEDIA, NON LA VARIANZA MEDIA!!!
deg = data[:,3].^(0.5)#./mean(data[:,3]);

file = "SHG_Pol_data.csv"
data = readdlm(dir*"\\"*file,',', comments = true, skipstart=1);
PWR_avg = mean(data[:,5]);
deg_avg = mean(data[:,6]);

rel_P = PWR ./ PWR_avg;
rel_d = deg ./ deg_avg; 

p = plot()

	plot!(tau, rel_P,
		label = "Laser Power",  color=ColorSchemes.RdBu_6[1])
	plot!(tau, rel_d,
		#ylabel="", #xticks=:none, xlabel="", grid=true, formatter=Returns(""),
		label = "Polarization Angle",  color=ColorSchemes.RdBu_6[6])

display(p)



# predirlength = length(dirname(@__DIR__));	# automatic name choice
# currentdir = @__DIR__;

# savefig(currentdir*'\\'*currentdir[(predirlength+3):end]*".pdf")