import allantools as al
import numpy as np
import matplotlib.pyplot as plt
import pandas as pd
import os

def ComputeAllan(data, mod='freq')->dict:
    
    # Compute variances
    data = np.array(data)
    datapts = len(data)
    taus = []                               # determine averaging periods tau (logarithmically); expected sampling period == 1 s
    interval = 1
    interfactor = 1

    while interval < datapts/2+1:           
        taus.append(interval)                                   
        interval *= 1.2                      # for exponantial progress of tau (less pts, more linear in log-plot)
        # interval += interfactor             # for "jumping" progress of tau (more pts, less linear in log-plot)
        # if interval % (6*interfactor) == 0:
        #     interval += interfactor
        # if interval % (8*interfactor) == 0:
        #     interfactor *= 10
        #     interval = interfactor
        
    taus = np.array(taus)
    return al.oadev(data, taus=taus, data_type=mod)
    
def ComputeAllan_from_file(date: str, filename: str):
    
    # import data
    df = pd.read_csv('DataRaw/'+ f'{date}/' + filename, sep=';', header=2, encoding='ISO-8859-1',names=['T [ms]','PW [W]','drop'])
    df = df.drop(labels = 'drop', axis=1)
    
    # Compute variances
    data = np.array(df).T
    (o_tau, o_dev, o_err, o_N) = ComputeAllan(data=data[1])
    
    # write to file in directory with same name
    directory_path = './DataVariances/' + date

    if not os.path.exists(directory_path):
        os.mkdir(directory_path)

    allanfile = f'{directory_path}/' + filename[:-4] + '_Variances.csv'
    AllanRes = {
    'o_tau': o_tau,
    'o_dev': o_dev,
    'o_err': o_err,
    }

    AllanData = pd.DataFrame(AllanRes)
    AllanData.to_csv(allanfile)


def PlotAllan(file_name: str):
    
    df = pd.read_csv(file_name)
    o_tau = df['o_tau']
    o_dev = df['o_dev']
    o_err = df['o_err']
    
    fig, ax = plt.subplots()                                                     # plots
    plottitle = file_name[25:-4]
    fig.suptitle(plottitle)

    ax.set_xscale('log')
    ax.set_yscale('log')
    ax.grid(visible=True, which='major', axis='both')
    ax.set(ylabel='Deviation')
    ax.errorbar(o_tau, o_dev, yerr=o_err, fmt='o-g', label='Overlapping Allan')
    ax.legend(loc='upper left')
    plt.show()