using DelimitedFiles
	using LaTeXStrings
	using Plots
	using Statistics

default(fontfamily = "Times",	# default plot parameters
	aspect_ratio = :auto,
	size = (888,500),
	margin = 0.5Plots.cm,
	markersize=3, markerstrokewidth=0, lw=5,
	legend=:topright, legendfontsize=12,
	tickfontsize=12, labelfontsize=14,
	xlabel="f [kHz]", ylabel="RIN [dB/Hz]",
	xlims=(10,250), ylims=(-175,-75),
	xticks=[25,50,75,100,125,150,175,200,225,250]#, yticks=[1e-21,1e-20,1e-19,1e-18]
	)


dir = @__DIR__
	filelist = readdir(dir)

for i =length(filelist):-1:1
	if !occursin(".csv", filelist[i])
			deleteat!(filelist, i)
	end
end

for i =length(filelist):-1:1
		if filelist[i][1:6] != "YE4140"
		   deleteat!(filelist, i)
	   end
end



## RIN YE4140

Idc40 = [2.34 0.941 0.189 0.01]*1.16e-3;
	G40 = 1e6;
	Rload = 1e3;
	Zin = 50;
	rbw = 1e3;
	ifile  = 1;
	dataSA = readdlm(dir*"\\"*filelist[ifile],',', comments = true);
	c40 = - 30 - 10*log10(rbw) - 20*log10(G40) + 10*log10(Zin);
	freq = dataSA[3:603,1]*1.0

p = plot(frame=:box, legend=:topright,
		legendfontsize=12, tickfontsize=12, lw=2)

for j=1:length(Idc40)
	lstr = string(Idc40[j]*1e3)
	lstr = lstr[1:4]* " mA";
	tmp = readdlm(dir*"\\"*filelist[j], ',',comments = true);
	rin = tmp[3:603,3]*1.0 .+ c40 .-20*log10(Idc40[j]);
	plot!(freq*1e-3, rin,
		lw=2, label = lstr, palette=:RdBu_4)
end
for j=1:length(Idc40)
	plot!(vec([0, 250]),10.0*log10(2*1.6e-19/Idc40[j] + 4*1.38e-23*300e-3/Idc40[j]^2)*vec([1 1]), lw=2,
		palette=:RdBu_4, ls=:dash, label=:false)
end
display(p)



predirlength = length(dirname(@__DIR__));	# automatic name choice
currentdir = @__DIR__;

savefig(currentdir*'\\'*currentdir[(predirlength+3):end]*".pdf")